==> haskell-ansi-terminal-types-0.11.5-142-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-yfu9gsm2DNJG8HNmJWdQG
key:                  ansi-terminal-types-0.11.5-yfu9gsm2DNJG8HNmJWdQG
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  9de3783788fc72b339fe9cbfda63a385
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-yfu9gsm2DNJG8HNmJWdQG
depends:              base-4.17.2.1 colour-2.3.6-D3OuYc0xuK09XFheGUPDon
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-types-0.11.5-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ansi-terminal-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ansi-terminal-types
version:              0.11.5
visibility:           public
id:                   ansi-terminal-types-0.11.5-BzqjqeGKAo35aChdQxZH3j
key:                  ansi-terminal-types-0.11.5-BzqjqeGKAo35aChdQxZH3j
license:              BSD-3-Clause
maintainer:
    Mike Pilgrem <public@pilgrem.com>, Roman Cheplyaka <roma@ro-che.info>

author:               Max Bolingbroke
homepage:             https://github.com/UnkindPartition/ansi-terminal
synopsis:             Types and functions used to represent SGR aspects
description:
    The \'\''ANSI\'\'' standards refer to the visual style of
    displaying characters as their \'\''graphic rendition\'\''. The
    \'\''ANSI\'\'' codes to establish the graphic rendition for
    subsequent text are referred to as SELECT GRAPHIC RENDITION
    (SGR). This package exposes modules that export types and
    functions used to represent SGR aspects.

category:             User Interfaces
abi:                  412950f0384c1d6e01bd2f524d57b13d
exposed:              True
exposed-modules:      System.Console.ANSI.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ansi-terminal-types-0.11.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ansi-terminal-types
hs-libraries:         HSansi-terminal-types-0.11.5-BzqjqeGKAo35aChdQxZH3j
depends:              base-4.17.2.1 colour-2.3.6-JZ2xJEG7ktI3yz7roXpz0n
haddock-interfaces:
    /usr/share/doc/haskell-ansi-terminal-types/html/ansi-terminal-types.haddock

haddock-html:         /usr/share/doc/haskell-ansi-terminal-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
